@@ -9,7 +9,7 @@ import attr
 import ddt
 from django.test import TestCase, override_settings
 
-from openedx_events.exceptions import InstantiationError, SenderValidationError
+from openedx_events.exceptions import SenderValidationError
 from openedx_events.tooling import OpenEdxPublicSignal
 
 
@@ -67,39 +67,18 @@ class OpenEdxPublicSignalTest(TestCase):
 
         self.assertDictContainsSubset(expected_metadata, attr.asdict(metadata))
 
-    @ddt.data(
-        ("", {"user": Mock()}, "event_type"),
-        ("org.openedx.learning.session.login.completed.v1", None, "data"),
-    )
-    @ddt.unpack
-    def test_event_instantiation_exception(
-        self, event_type, event_data, missing_argument
-    ):
-        """
-        This method tests when an event is instantiated without event_type or
-        event data.
-
-        Expected behavior:
-            An InstantiationError exception is raised.
-        """
-        exception_message = "InstantiationError {event_type}: Missing required argument '{missing_argument}'".format(
-            event_type=event_type, missing_argument=missing_argument
-        )
-
-        with self.assertRaisesMessage(InstantiationError, exception_message):
-            OpenEdxPublicSignal(event_type=event_type, data=event_data)
-
     @patch("openedx_events.tooling.OpenEdxPublicSignal.generate_signal_metadata")
     @patch("openedx_events.tooling.Signal.send")
     def test_send_event_successfully(self, send_mock, fake_metadata):
         """
-        This method tests the process of sending an event.
+        This method tests the process of sending an event that's allow to fail.
 
         Expected behavior:
-            The event is sent as a django signal.
+            The event is sent as a django signal with send method.
         """
         expected_metadata = Mock(some_data="some_data")
         fake_metadata.return_value = expected_metadata
+        self.public_signal.allow_send_event_failure()
 
         self.public_signal.send_event(user=self.user_mock)
 
@@ -113,15 +92,16 @@ class OpenEdxPublicSignalTest(TestCase):
     @patch("openedx_events.tooling.Signal.send_robust")
     def test_send_robust_event_successfully(self, send_robust_mock, fake_metadata):
         """
-        This method tests the process of sending an event.
+        This method tests the process of sending an event that won't crash.
 
         Expected behavior:
-            The event is sent as a django signal.
+            The event is sent as a django signal with send_robust method.
         """
         expected_metadata = Mock(some_data="some_data")
         fake_metadata.return_value = expected_metadata
+        send_robust_mock.return_value.__name__ = "func_name"
 
-        self.public_signal.send_event(user=self.user_mock, send_robust=True)
+        self.public_signal.send_event(user=self.user_mock)
 
         send_robust_mock.assert_called_once_with(
             sender=None,
